Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2068)

Unified Diff: chrome/browser/extensions/extension_view.cc

Issue 114059: Refactors HWNDView, NativeViewHostGtk and NativeViewHost so that they match t... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 11 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/extensions/extension_view.h ('k') | chrome/browser/views/about_ipc_dialog.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/extensions/extension_view.cc
===================================================================
--- chrome/browser/extensions/extension_view.cc (revision 17161)
+++ chrome/browser/extensions/extension_view.cc (working copy)
@@ -20,13 +20,13 @@
}
ExtensionView::~ExtensionView() {
- if (GetHWND())
+ if (native_view())
Detach();
}
void ExtensionView::SetVisible(bool is_visible) {
if (is_visible != IsVisible()) {
- HWNDView::SetVisible(is_visible);
+ NativeViewHost::SetVisible(is_visible);
// Also tell RenderWidgetHostView the new visibility. Despite its name, it
// is not part of the View heirarchy and does not know about the change
@@ -47,7 +47,7 @@
if (render_view_host()->view() && !current.IsEmpty())
render_view_host()->view()->SetSize(gfx::Size(width(), height()));
// Layout is where the HWND is properly positioned.
// TODO(erikkay) - perhaps this should be in HWNDView
Layout();
}
« no previous file with comments | « chrome/browser/extensions/extension_view.h ('k') | chrome/browser/views/about_ipc_dialog.h » ('j') | no next file with comments »
@@ -47,7 +47,7 @@
render_view_host()->view()->SetSize(gfx::Size(width(), height()));
// Layout is where the HWND is properly positioned.
- // TODO(erikkay) - perhaps this should be in HWNDView
+ // TODO(erikkay) - perhaps this should be in NativeViewHost
Layout();
}

Powered by Google App Engine
This is Rietveld 408576698